@@ -39,11 +39,41 @@ sub new {
 	$self->StyleSetForeground( 13, Wx::Colour->new( 0x40, 0x80, 0xff ) );
 	$self->StyleSetForeground( 17, Wx::Colour->new( 0xff, 0x00, 0x7f ) );
 	$self->StyleSetForeground( 18, Wx::Colour->new( 0x7f, 0x7f, 0x00 ) );
-	$self->StyleSetBold( 12, 1 );
+	$self->StyleSetBold( 5, 1 );
 	$self->StyleSetSpec( wxSTC_H_TAG, "fore:#0000ff" );
 
 	# set the lexer to Perl 5
 	$self->SetLexer(wxSTC_LEX_PERL);
+	my @keywords = qw(
+		NULL __FILE__ __LINE__ __PACKAGE__ __DATA__ __END__ AUTOLOAD
+		BEGIN CORE DESTROY END EQ GE GT INIT LE LT NE CHECK abs accept
+		alarm and atan2 bind binmode bless caller chdir chmod chomp chop
+		chown chr chroot close closedir cmp connect continue cos crypt
+		dbmclose dbmopen defined delete die do dump each else elsif endgrent
+		endhostent endnetent endprotoent endpwent endservent eof eq eval
+		exec exists exit exp fcntl fileno flock for foreach fork format
+		formline ge getc getgrent getgrgid getgrnam gethostbyaddr gethostbyname
+		gethostent getlogin getnetbyaddr getnetbyname getnetent getpeername
+		getpgrp getppid getpriority getprotobyname getprotobynumber getprotoent
+		getpwent getpwnam getpwuid getservbyname getservbyport getservent
+		getsockname getsockopt glob gmtime goto grep gt hex if index
+		int ioctl join keys kill last lc lcfirst le length link listen
+		local localtime lock log lstat lt map mkdir msgctl msgget msgrcv
+		msgsnd my ne next no not oct open opendir or ord our pack package
+		pipe pop pos print printf prototype push quotemeta qu
+		rand read readdir readline readlink readpipe recv redo
+		ref rename require reset return reverse rewinddir rindex rmdir
+		scalar seek seekdir select semctl semget semop send setgrent
+		sethostent setnetent setpgrp setpriority setprotoent setpwent
+		setservent setsockopt shift shmctl shmget shmread shmwrite shutdown
+		sin sleep socket socketpair sort splice split sprintf sqrt srand
+		stat study sub substr symlink syscall sysopen sysread sysseek
+		system syswrite tell telldir tie tied time times truncate
+		uc ucfirst umask undef unless unlink unpack unshift untie until
+		use utime values vec wait waitpid wantarray warn while write
+		xor given when default say state UNITCHECK
+	);
+	$self->SetKeyWords(0, join(' ', @keywords));
 
 	$self->SetText(<<'EXAMPLE');
 # Perl 5 example
